@@ -9,6 +9,7 @@ library(htmlTable)
 
 ## ---- message = FALSE,include = TRUE------------------------------------------
 library(scipub)
+data(psydat)
 
 ## -----------------------------------------------------------------------------
 apastat(stats::cor.test(psydat$Age, psydat$Height), ci = TRUE)
@@ -69,3 +70,9 @@ temp <- data.frame(iq=psydat$iq, iq_winsor=winsorZ(psydat$iq), iq_outlier = wins
 summary(temp)
 ggplot(temp[!is.na(temp$iq),], aes(x=iq, y=iq_winsor)) + geom_point(aes(color=iq_outlier),alpha=.7) + geom_line() + theme_bw()
 
+## ----results="asis"-----------------------------------------------------------
+gg_groupplot(data=psydat, x="Sex", y="depressT")
+
+## ----results="asis"-----------------------------------------------------------
+gg_groupplot(data=psydat, x="Income", y="depressT") + facet_wrap(~Sex) + theme(axis.text.x = element_text(angle = 45, vjust = 1, hjust=1))
+
